@@ -1,11 +1,10 @@
 import logging
 import os
-import re
 import shutil
 import subprocess
 import sys
 from pathlib import Path
-from typing import List, Sequence, Tuple, Union, Optional
+from typing import List, Optional, Sequence, Tuple, Union
 
 from pipx.constants import WINDOWS
 
@@ -99,13 +98,15 @@ def run_subprocess(
     #   dependencies are in the venv path (#233)
     # Remove __PYVENV_LAUNCHER__ because it can cause the wrong python binary
     #   to be used (#334)
-    env_blacklist = ["PYTHONPATH", "__PYVENV_LAUNCHER__"]
-    for env_to_remove in env_blacklist:
+    env_blocklist = ["PYTHONPATH", "__PYVENV_LAUNCHER__"]
+    for env_to_remove in env_blocklist:
         env.pop(env_to_remove, None)
 
     env["PIP_DISABLE_PIP_VERSION_CHECK"] = "1"
     # Make sure that Python writes output in UTF-8
     env["PYTHONIOENCODING"] = "utf-8"
+    # Make sure we install package to venv, not userbase dir
+    env["PIP_USER"] = "0"
 
     if log_cmd_str is None:
         log_cmd_str = " ".join(str(c) for c in cmd)
@@ -135,13 +136,6 @@ def run(cmd: Sequence[Union[str, Path]], check=True) -> int:
     return returncode
 
 
-def valid_pypi_name(package_name: str) -> bool:
-    # https://www.python.org/dev/peps/pep-0508/#names
-    return bool(
-        re.search(r"^([A-Z0-9]|[A-Z0-9][A-Z0-9._-]*[A-Z0-9])$", package_name, re.I)
-    )
-
-
 def full_package_description(package: str, package_spec: str) -> str:
     if package == package_spec:
         return package
